==> ejc-lz-impl-3.0.0-20220420.130025-56-sources.jar: com/ejianc/business/base/bean/ShippersEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运输商基本档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_shippers")
public class ShippersEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="name")
    private String name; // 运输商名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private String operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="shippers_manage_id")
    private Long shippersManageId; // 运输商管理id
    @TableField(value="shippers_manage_name")
    private String shippersManageName; // 运输商管理id
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="business_license")
    private String businessLicense; // 营业执照号
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="category_id")
    private Long categoryId; // 分类id
    @TableField(value="category_name")
    private String categoryName; // 分类名称
    @TableField(value="category")
    private Integer category; // 分类名称1 销售 2 采购 3 销售和采购

    @TableField(exist=false)
    @SubEntity(serviceName="shippersfareService",pidName = "mid")
    private List<ShippersfareEntity> shippersfareEntities = new ArrayList<>(); // 运费维护子表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public Long getShippersManageId() {
        return shippersManageId;
    }

    public void setShippersManageId(Long shippersManageId) {
        this.shippersManageId = shippersManageId;
    }

    public String getShippersManageName() {
        return shippersManageName;
    }

    public void setShippersManageName(String shippersManageName) {
        this.shippersManageName = shippersManageName;
    }

    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }

    public String getBusinessLicense() {
        return businessLicense;
    }

    public void setBusinessLicense(String businessLicense) {
        this.businessLicense = businessLicense;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public List<ShippersfareEntity> getShippersfareEntities() {
        return shippersfareEntities;
    }

    public void setShippersfareEntities(List<ShippersfareEntity> shippersfareEntities) {
        this.shippersfareEntities = shippersfareEntities;
    }

    public Integer getCategory() {
        return category;
    }

    public void setCategory(Integer category) {
        this.category = category;
    }
}

==> ejc-lz-impl-3.0.0-20220427.010753-66-sources.jar: com/ejianc/business/base/bean/ShippersEntity.java <==
package com.ejianc.business.base.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 运输商基本档案
 * 
 * @author generator
 * 
 */
 @TableName("ejc_base_shippers")
public class ShippersEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="name")
    private String name; // 运输商名称
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 项目部id
    @TableField(value="operator_id")
    private String operatorId; // 经办人id
    @TableField(value="operator_name")
    private String operatorName; // 经办人名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private Long changeId; // 变更单据id
    @TableField(value="change_state")
    private String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="shippers_manage_id")
    private Long shippersManageId; // 运输商管理id
    @TableField(value="shippers_manage_name")
    private String shippersManageName; // 运输商管理id
    @TableField(value="legal_person")
    private String legalPerson; // 法人
    @TableField(value="business_license")
    private String businessLicense; // 营业执照号
    @TableField(value="address")
    private String address; // 地址
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="category_id")
    private Long categoryId; // 分类id
    @TableField(value="category_name")
    private String categoryName; // 分类名称
    @TableField(value="category")
    private Integer category; // 分类名称1 销售 2 采购 3 销售和采购
    @TableField(value="transport_fare")
    private BigDecimal transportFare; // 运输单价

    @TableField(exist=false)
    @SubEntity(serviceName="shippersfareService",pidName = "mid")
    private List<ShippersfareEntity> shippersfareEntities = new ArrayList<>(); // 运费维护子表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }
    public String getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(String operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public String getChangeState() {
        return changeState;
    }

    public void setChangeState(String changeState) {
        this.changeState = changeState;
    }

    public Long getShippersManageId() {
        return shippersManageId;
    }

    public void setShippersManageId(Long shippersManageId) {
        this.shippersManageId = shippersManageId;
    }

    public String getShippersManageName() {
        return shippersManageName;
    }

    public void setShippersManageName(String shippersManageName) {
        this.shippersManageName = shippersManageName;
    }

    public String getLegalPerson() {
        return legalPerson;
    }

    public void setLegalPerson(String legalPerson) {
        this.legalPerson = legalPerson;
    }

    public String getBusinessLicense() {
        return businessLicense;
    }

    public void setBusinessLicense(String businessLicense) {
        this.businessLicense = businessLicense;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public Long getCategoryId() {
        return categoryId;
    }

    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }

    public String getCategoryName() {
        return categoryName;
    }

    public void setCategoryName(String categoryName) {
        this.categoryName = categoryName;
    }

    public List<ShippersfareEntity> getShippersfareEntities() {
        return shippersfareEntities;
    }

    public void setShippersfareEntities(List<ShippersfareEntity> shippersfareEntities) {
        this.shippersfareEntities = shippersfareEntities;
    }

    public Integer getCategory() {
        return category;
    }

    public void setCategory(Integer category) {
        this.category = category;
    }

    public BigDecimal getTransportFare() {
        return transportFare;
    }

    public void setTransportFare(BigDecimal transportFare) {
        this.transportFare = transportFare;
    }
}
